/**
 * apeman app to parse request body.
 * @memberof module:apeman-app-form/lib
 * @function create
 * @param {object} [options] - Optional settings.
 * @param {string} [options.body='body'] - Property name of req for body data.
 * @param {string} [options.files='files'] - Property name of req for files data.
 * @returns {function} - Defined app function.
 */

"use strict";

var argx = require('argx'),
    async = require('async'),
    formidable = require('formidable'),
    objnest = require('objnest');

/** @lends create */
function create(options) {
    var args = argx(arguments);
    options = objnest.expand(args.pop('object') || {});

    var bodyName = options.body || 'body',
        filesName = options.files || 'files';

    var Form = formidable.IncomingForm;

    /**
     * Defined app.
     * @function app
     * @param {object} req - Request object.
     * @param {object} res - Response object.
     * @param {function} next - Pass to next handler.
     */
    function app(req, res, next) {
        async.waterfall([
            function (callback) {
                new Form(options).parse(req, callback);
            },
            function (body, files, callback) {
                console.log(arguments);
                req[bodyName] = body;
                req[filesName] = files;
                callback();
            }
        ], next);
    }

    // Description of this app.
    app.$desc = "Parse request body";
    return app;
}

module.exports = create;
